# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'SearchIndexSchemaArgs',
    'SearchIndexSchemaArgsDict',
    'SearchIndexSchemaFieldSchemaArgs',
    'SearchIndexSchemaFieldSchemaArgsDict',
    'SearchIndexSchemaIndexSettingArgs',
    'SearchIndexSchemaIndexSettingArgsDict',
    'SearchIndexSchemaIndexSortArgs',
    'SearchIndexSchemaIndexSortArgsDict',
    'SearchIndexSchemaIndexSortSorterArgs',
    'SearchIndexSchemaIndexSortSorterArgsDict',
    'TableDefinedColumnArgs',
    'TableDefinedColumnArgsDict',
    'TablePrimaryKeyArgs',
    'TablePrimaryKeyArgsDict',
    'TunnelChannelArgs',
    'TunnelChannelArgsDict',
]

MYPY = False

if not MYPY:
    class SearchIndexSchemaArgsDict(TypedDict):
        field_schemas: pulumi.Input[Sequence[pulumi.Input['SearchIndexSchemaFieldSchemaArgsDict']]]
        """
        A list of field schemas. See `field_schema` below.
        """
        index_settings: NotRequired[pulumi.Input[Sequence[pulumi.Input['SearchIndexSchemaIndexSettingArgsDict']]]]
        """
        The settings of the search index, including routingFields. See `index_setting` below.
        """
        index_sorts: NotRequired[pulumi.Input[Sequence[pulumi.Input['SearchIndexSchemaIndexSortArgsDict']]]]
        """
        The presorting settings of the search index, including sorters. If no value is specified for the indexSort parameter, field values are sorted by primary key by default. See `index_sort` below.
        """
elif False:
    SearchIndexSchemaArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class SearchIndexSchemaArgs:
    def __init__(__self__, *,
                 field_schemas: pulumi.Input[Sequence[pulumi.Input['SearchIndexSchemaFieldSchemaArgs']]],
                 index_settings: Optional[pulumi.Input[Sequence[pulumi.Input['SearchIndexSchemaIndexSettingArgs']]]] = None,
                 index_sorts: Optional[pulumi.Input[Sequence[pulumi.Input['SearchIndexSchemaIndexSortArgs']]]] = None):
        """
        :param pulumi.Input[Sequence[pulumi.Input['SearchIndexSchemaFieldSchemaArgs']]] field_schemas: A list of field schemas. See `field_schema` below.
        :param pulumi.Input[Sequence[pulumi.Input['SearchIndexSchemaIndexSettingArgs']]] index_settings: The settings of the search index, including routingFields. See `index_setting` below.
        :param pulumi.Input[Sequence[pulumi.Input['SearchIndexSchemaIndexSortArgs']]] index_sorts: The presorting settings of the search index, including sorters. If no value is specified for the indexSort parameter, field values are sorted by primary key by default. See `index_sort` below.
        """
        pulumi.set(__self__, "field_schemas", field_schemas)
        if index_settings is not None:
            pulumi.set(__self__, "index_settings", index_settings)
        if index_sorts is not None:
            pulumi.set(__self__, "index_sorts", index_sorts)

    @property
    @pulumi.getter(name="fieldSchemas")
    def field_schemas(self) -> pulumi.Input[Sequence[pulumi.Input['SearchIndexSchemaFieldSchemaArgs']]]:
        """
        A list of field schemas. See `field_schema` below.
        """
        return pulumi.get(self, "field_schemas")

    @field_schemas.setter
    def field_schemas(self, value: pulumi.Input[Sequence[pulumi.Input['SearchIndexSchemaFieldSchemaArgs']]]):
        pulumi.set(self, "field_schemas", value)

    @property
    @pulumi.getter(name="indexSettings")
    def index_settings(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['SearchIndexSchemaIndexSettingArgs']]]]:
        """
        The settings of the search index, including routingFields. See `index_setting` below.
        """
        return pulumi.get(self, "index_settings")

    @index_settings.setter
    def index_settings(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['SearchIndexSchemaIndexSettingArgs']]]]):
        pulumi.set(self, "index_settings", value)

    @property
    @pulumi.getter(name="indexSorts")
    def index_sorts(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['SearchIndexSchemaIndexSortArgs']]]]:
        """
        The presorting settings of the search index, including sorters. If no value is specified for the indexSort parameter, field values are sorted by primary key by default. See `index_sort` below.
        """
        return pulumi.get(self, "index_sorts")

    @index_sorts.setter
    def index_sorts(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['SearchIndexSchemaIndexSortArgs']]]]):
        pulumi.set(self, "index_sorts", value)


if not MYPY:
    class SearchIndexSchemaFieldSchemaArgsDict(TypedDict):
        field_name: pulumi.Input[str]
        """
        The name of the field that is used to sort data. only required if sorter_type is FieldSort.
        """
        field_type: pulumi.Input[str]
        """
        Specifies the type of the field. Use FieldType.XXX to set the type.
        """
        analyzer: NotRequired[pulumi.Input[str]]
        """
        Specifies the type of the analyzer that you want to use. If fieldType is set to Text, you can configure this parameter. Otherwise, the default analyzer type single-word tokenization is used.
        """
        enable_sort_and_agg: NotRequired[pulumi.Input[bool]]
        """
        Specifies whether to enable sorting and aggregation. Type: Boolean. Sorting can be enabled only for fields for which enable_sort_and_agg is set to true.
        """
        index: NotRequired[pulumi.Input[bool]]
        """
        Specifies whether to enable indexing for the column. Type: Boolean.
        """
        is_array: NotRequired[pulumi.Input[bool]]
        """
        Specifies whether the value is an array. Type: Boolean.
        """
        store: NotRequired[pulumi.Input[bool]]
        """
        Specifies whether to store the value of the field in the search index. Type: Boolean. If you set store to true, you can read the value of the field from the search index without querying the data table. This improves query performance.
        """
elif False:
    SearchIndexSchemaFieldSchemaArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class SearchIndexSchemaFieldSchemaArgs:
    def __init__(__self__, *,
                 field_name: pulumi.Input[str],
                 field_type: pulumi.Input[str],
                 analyzer: Optional[pulumi.Input[str]] = None,
                 enable_sort_and_agg: Optional[pulumi.Input[bool]] = None,
                 index: Optional[pulumi.Input[bool]] = None,
                 is_array: Optional[pulumi.Input[bool]] = None,
                 store: Optional[pulumi.Input[bool]] = None):
        """
        :param pulumi.Input[str] field_name: The name of the field that is used to sort data. only required if sorter_type is FieldSort.
        :param pulumi.Input[str] field_type: Specifies the type of the field. Use FieldType.XXX to set the type.
        :param pulumi.Input[str] analyzer: Specifies the type of the analyzer that you want to use. If fieldType is set to Text, you can configure this parameter. Otherwise, the default analyzer type single-word tokenization is used.
        :param pulumi.Input[bool] enable_sort_and_agg: Specifies whether to enable sorting and aggregation. Type: Boolean. Sorting can be enabled only for fields for which enable_sort_and_agg is set to true.
        :param pulumi.Input[bool] index: Specifies whether to enable indexing for the column. Type: Boolean.
        :param pulumi.Input[bool] is_array: Specifies whether the value is an array. Type: Boolean.
        :param pulumi.Input[bool] store: Specifies whether to store the value of the field in the search index. Type: Boolean. If you set store to true, you can read the value of the field from the search index without querying the data table. This improves query performance.
        """
        pulumi.set(__self__, "field_name", field_name)
        pulumi.set(__self__, "field_type", field_type)
        if analyzer is not None:
            pulumi.set(__self__, "analyzer", analyzer)
        if enable_sort_and_agg is not None:
            pulumi.set(__self__, "enable_sort_and_agg", enable_sort_and_agg)
        if index is not None:
            pulumi.set(__self__, "index", index)
        if is_array is not None:
            pulumi.set(__self__, "is_array", is_array)
        if store is not None:
            pulumi.set(__self__, "store", store)

    @property
    @pulumi.getter(name="fieldName")
    def field_name(self) -> pulumi.Input[str]:
        """
        The name of the field that is used to sort data. only required if sorter_type is FieldSort.
        """
        return pulumi.get(self, "field_name")

    @field_name.setter
    def field_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "field_name", value)

    @property
    @pulumi.getter(name="fieldType")
    def field_type(self) -> pulumi.Input[str]:
        """
        Specifies the type of the field. Use FieldType.XXX to set the type.
        """
        return pulumi.get(self, "field_type")

    @field_type.setter
    def field_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "field_type", value)

    @property
    @pulumi.getter
    def analyzer(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the type of the analyzer that you want to use. If fieldType is set to Text, you can configure this parameter. Otherwise, the default analyzer type single-word tokenization is used.
        """
        return pulumi.get(self, "analyzer")

    @analyzer.setter
    def analyzer(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "analyzer", value)

    @property
    @pulumi.getter(name="enableSortAndAgg")
    def enable_sort_and_agg(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies whether to enable sorting and aggregation. Type: Boolean. Sorting can be enabled only for fields for which enable_sort_and_agg is set to true.
        """
        return pulumi.get(self, "enable_sort_and_agg")

    @enable_sort_and_agg.setter
    def enable_sort_and_agg(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "enable_sort_and_agg", value)

    @property
    @pulumi.getter
    def index(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies whether to enable indexing for the column. Type: Boolean.
        """
        return pulumi.get(self, "index")

    @index.setter
    def index(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "index", value)

    @property
    @pulumi.getter(name="isArray")
    def is_array(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies whether the value is an array. Type: Boolean.
        """
        return pulumi.get(self, "is_array")

    @is_array.setter
    def is_array(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_array", value)

    @property
    @pulumi.getter
    def store(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies whether to store the value of the field in the search index. Type: Boolean. If you set store to true, you can read the value of the field from the search index without querying the data table. This improves query performance.
        """
        return pulumi.get(self, "store")

    @store.setter
    def store(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "store", value)


if not MYPY:
    class SearchIndexSchemaIndexSettingArgsDict(TypedDict):
        routing_fields: NotRequired[pulumi.Input[Sequence[pulumi.Input[str]]]]
        """
        Specifies custom routing fields. You can specify some primary key columns as routing fields. Tablestore distributes data that is written to a search index across different partitions based on the specified routing fields. The data whose routing field values are the same is distributed to the same partition.
        """
elif False:
    SearchIndexSchemaIndexSettingArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class SearchIndexSchemaIndexSettingArgs:
    def __init__(__self__, *,
                 routing_fields: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        :param pulumi.Input[Sequence[pulumi.Input[str]]] routing_fields: Specifies custom routing fields. You can specify some primary key columns as routing fields. Tablestore distributes data that is written to a search index across different partitions based on the specified routing fields. The data whose routing field values are the same is distributed to the same partition.
        """
        if routing_fields is not None:
            pulumi.set(__self__, "routing_fields", routing_fields)

    @property
    @pulumi.getter(name="routingFields")
    def routing_fields(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Specifies custom routing fields. You can specify some primary key columns as routing fields. Tablestore distributes data that is written to a search index across different partitions based on the specified routing fields. The data whose routing field values are the same is distributed to the same partition.
        """
        return pulumi.get(self, "routing_fields")

    @routing_fields.setter
    def routing_fields(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "routing_fields", value)


if not MYPY:
    class SearchIndexSchemaIndexSortArgsDict(TypedDict):
        sorters: pulumi.Input[Sequence[pulumi.Input['SearchIndexSchemaIndexSortSorterArgsDict']]]
        """
        Specifies the presorting method for the search index. PrimaryKeySort and FieldSort are supported. See `sorter` below.
        """
elif False:
    SearchIndexSchemaIndexSortArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class SearchIndexSchemaIndexSortArgs:
    def __init__(__self__, *,
                 sorters: pulumi.Input[Sequence[pulumi.Input['SearchIndexSchemaIndexSortSorterArgs']]]):
        """
        :param pulumi.Input[Sequence[pulumi.Input['SearchIndexSchemaIndexSortSorterArgs']]] sorters: Specifies the presorting method for the search index. PrimaryKeySort and FieldSort are supported. See `sorter` below.
        """
        pulumi.set(__self__, "sorters", sorters)

    @property
    @pulumi.getter
    def sorters(self) -> pulumi.Input[Sequence[pulumi.Input['SearchIndexSchemaIndexSortSorterArgs']]]:
        """
        Specifies the presorting method for the search index. PrimaryKeySort and FieldSort are supported. See `sorter` below.
        """
        return pulumi.get(self, "sorters")

    @sorters.setter
    def sorters(self, value: pulumi.Input[Sequence[pulumi.Input['SearchIndexSchemaIndexSortSorterArgs']]]):
        pulumi.set(self, "sorters", value)


if not MYPY:
    class SearchIndexSchemaIndexSortSorterArgsDict(TypedDict):
        field_name: NotRequired[pulumi.Input[str]]
        """
        The name of the field that is used to sort data. only required if sorter_type is FieldSort.
        """
        mode: NotRequired[pulumi.Input[str]]
        """
        The sorting method that is used when the field contains multiple values. valid values: `Min`, `Max`, `Avg`. only required if sorter_type is FieldSort.
        """
        order: NotRequired[pulumi.Input[str]]
        """
        The sort order. Data can be sorted in ascending(`Asc`) or descending(`Desc`) order. Default value: `Asc`.
        """
        sorter_type: NotRequired[pulumi.Input[str]]
        """
        Data is sorted by Which fields or keys. valid values: `PrimaryKeySort`, `FieldSort`.
        """
elif False:
    SearchIndexSchemaIndexSortSorterArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class SearchIndexSchemaIndexSortSorterArgs:
    def __init__(__self__, *,
                 field_name: Optional[pulumi.Input[str]] = None,
                 mode: Optional[pulumi.Input[str]] = None,
                 order: Optional[pulumi.Input[str]] = None,
                 sorter_type: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] field_name: The name of the field that is used to sort data. only required if sorter_type is FieldSort.
        :param pulumi.Input[str] mode: The sorting method that is used when the field contains multiple values. valid values: `Min`, `Max`, `Avg`. only required if sorter_type is FieldSort.
        :param pulumi.Input[str] order: The sort order. Data can be sorted in ascending(`Asc`) or descending(`Desc`) order. Default value: `Asc`.
        :param pulumi.Input[str] sorter_type: Data is sorted by Which fields or keys. valid values: `PrimaryKeySort`, `FieldSort`.
        """
        if field_name is not None:
            pulumi.set(__self__, "field_name", field_name)
        if mode is not None:
            pulumi.set(__self__, "mode", mode)
        if order is not None:
            pulumi.set(__self__, "order", order)
        if sorter_type is not None:
            pulumi.set(__self__, "sorter_type", sorter_type)

    @property
    @pulumi.getter(name="fieldName")
    def field_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the field that is used to sort data. only required if sorter_type is FieldSort.
        """
        return pulumi.get(self, "field_name")

    @field_name.setter
    def field_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "field_name", value)

    @property
    @pulumi.getter
    def mode(self) -> Optional[pulumi.Input[str]]:
        """
        The sorting method that is used when the field contains multiple values. valid values: `Min`, `Max`, `Avg`. only required if sorter_type is FieldSort.
        """
        return pulumi.get(self, "mode")

    @mode.setter
    def mode(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "mode", value)

    @property
    @pulumi.getter
    def order(self) -> Optional[pulumi.Input[str]]:
        """
        The sort order. Data can be sorted in ascending(`Asc`) or descending(`Desc`) order. Default value: `Asc`.
        """
        return pulumi.get(self, "order")

    @order.setter
    def order(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "order", value)

    @property
    @pulumi.getter(name="sorterType")
    def sorter_type(self) -> Optional[pulumi.Input[str]]:
        """
        Data is sorted by Which fields or keys. valid values: `PrimaryKeySort`, `FieldSort`.
        """
        return pulumi.get(self, "sorter_type")

    @sorter_type.setter
    def sorter_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "sorter_type", value)


if not MYPY:
    class TableDefinedColumnArgsDict(TypedDict):
        name: pulumi.Input[str]
        """
        Name for defined column.
        """
        type: pulumi.Input[str]
        """
        Type for defined column. `Integer`, `String`, `Binary`, `Double`, `Boolean` is allowed.
        """
elif False:
    TableDefinedColumnArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class TableDefinedColumnArgs:
    def __init__(__self__, *,
                 name: pulumi.Input[str],
                 type: pulumi.Input[str]):
        """
        :param pulumi.Input[str] name: Name for defined column.
        :param pulumi.Input[str] type: Type for defined column. `Integer`, `String`, `Binary`, `Double`, `Boolean` is allowed.
        """
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[str]:
        """
        Name for defined column.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def type(self) -> pulumi.Input[str]:
        """
        Type for defined column. `Integer`, `String`, `Binary`, `Double`, `Boolean` is allowed.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[str]):
        pulumi.set(self, "type", value)


if not MYPY:
    class TablePrimaryKeyArgsDict(TypedDict):
        name: pulumi.Input[str]
        """
        Name for primary key.
        """
        type: pulumi.Input[str]
        """
        Type for primary key. Only `Integer`, `String` or `Binary` is allowed.
        """
elif False:
    TablePrimaryKeyArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class TablePrimaryKeyArgs:
    def __init__(__self__, *,
                 name: pulumi.Input[str],
                 type: pulumi.Input[str]):
        """
        :param pulumi.Input[str] name: Name for primary key.
        :param pulumi.Input[str] type: Type for primary key. Only `Integer`, `String` or `Binary` is allowed.
        """
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[str]:
        """
        Name for primary key.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def type(self) -> pulumi.Input[str]:
        """
        Type for primary key. Only `Integer`, `String` or `Binary` is allowed.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[str]):
        pulumi.set(self, "type", value)


if not MYPY:
    class TunnelChannelArgsDict(TypedDict):
        channel_id: NotRequired[pulumi.Input[str]]
        """
        The id of the channel.
        """
        channel_rpo: NotRequired[pulumi.Input[int]]
        """
        The latest consumption time of the channel, unix time in nanosecond.
        """
        channel_status: NotRequired[pulumi.Input[str]]
        """
        The status of the channel, valid values: `WAIT`, `OPEN`, `CLOSING`, `CLOSE`, `TERMINATED`.
        """
        channel_type: NotRequired[pulumi.Input[str]]
        """
        The type of the channel, valid values: `BaseData`, `Stream`.
        """
        client_id: NotRequired[pulumi.Input[str]]
        """
        The client id of the channel.
        """
elif False:
    TunnelChannelArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class TunnelChannelArgs:
    def __init__(__self__, *,
                 channel_id: Optional[pulumi.Input[str]] = None,
                 channel_rpo: Optional[pulumi.Input[int]] = None,
                 channel_status: Optional[pulumi.Input[str]] = None,
                 channel_type: Optional[pulumi.Input[str]] = None,
                 client_id: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] channel_id: The id of the channel.
        :param pulumi.Input[int] channel_rpo: The latest consumption time of the channel, unix time in nanosecond.
        :param pulumi.Input[str] channel_status: The status of the channel, valid values: `WAIT`, `OPEN`, `CLOSING`, `CLOSE`, `TERMINATED`.
        :param pulumi.Input[str] channel_type: The type of the channel, valid values: `BaseData`, `Stream`.
        :param pulumi.Input[str] client_id: The client id of the channel.
        """
        if channel_id is not None:
            pulumi.set(__self__, "channel_id", channel_id)
        if channel_rpo is not None:
            pulumi.set(__self__, "channel_rpo", channel_rpo)
        if channel_status is not None:
            pulumi.set(__self__, "channel_status", channel_status)
        if channel_type is not None:
            pulumi.set(__self__, "channel_type", channel_type)
        if client_id is not None:
            pulumi.set(__self__, "client_id", client_id)

    @property
    @pulumi.getter(name="channelId")
    def channel_id(self) -> Optional[pulumi.Input[str]]:
        """
        The id of the channel.
        """
        return pulumi.get(self, "channel_id")

    @channel_id.setter
    def channel_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "channel_id", value)

    @property
    @pulumi.getter(name="channelRpo")
    def channel_rpo(self) -> Optional[pulumi.Input[int]]:
        """
        The latest consumption time of the channel, unix time in nanosecond.
        """
        return pulumi.get(self, "channel_rpo")

    @channel_rpo.setter
    def channel_rpo(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "channel_rpo", value)

    @property
    @pulumi.getter(name="channelStatus")
    def channel_status(self) -> Optional[pulumi.Input[str]]:
        """
        The status of the channel, valid values: `WAIT`, `OPEN`, `CLOSING`, `CLOSE`, `TERMINATED`.
        """
        return pulumi.get(self, "channel_status")

    @channel_status.setter
    def channel_status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "channel_status", value)

    @property
    @pulumi.getter(name="channelType")
    def channel_type(self) -> Optional[pulumi.Input[str]]:
        """
        The type of the channel, valid values: `BaseData`, `Stream`.
        """
        return pulumi.get(self, "channel_type")

    @channel_type.setter
    def channel_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "channel_type", value)

    @property
    @pulumi.getter(name="clientId")
    def client_id(self) -> Optional[pulumi.Input[str]]:
        """
        The client id of the channel.
        """
        return pulumi.get(self, "client_id")

    @client_id.setter
    def client_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "client_id", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['OrderArgs', 'Order']

@pulumi.input_type
class OrderArgs:
    def __init__(__self__, *,
                 package_version: pulumi.Input[str],
                 pricing_cycle: pulumi.Input[str],
                 product_code: pulumi.Input[str],
                 components: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 coupon_id: Optional[pulumi.Input[str]] = None,
                 duration: Optional[pulumi.Input[int]] = None,
                 pay_type: Optional[pulumi.Input[str]] = None,
                 quantity: Optional[pulumi.Input[int]] = None):
        """
        The set of arguments for constructing a Order resource.
        :param pulumi.Input[str] package_version: The package version of the market product.
        :param pulumi.Input[str] pricing_cycle: The purchase cycle of the product, valid values are `Day`, `Month` and `Year`.
        :param pulumi.Input[str] product_code: The product_code of market place product.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] components: Service providers customize additional components.
        :param pulumi.Input[str] coupon_id: The coupon id of the market product.
        :param pulumi.Input[int] duration: The number of purchase cycles.
        :param pulumi.Input[str] pay_type: Valid values are `PrePaid`, `PostPaid`,System default to `PostPaid`.
        :param pulumi.Input[int] quantity: The quantity of the market product will be purchased.
        """
        pulumi.set(__self__, "package_version", package_version)
        pulumi.set(__self__, "pricing_cycle", pricing_cycle)
        pulumi.set(__self__, "product_code", product_code)
        if components is not None:
            pulumi.set(__self__, "components", components)
        if coupon_id is not None:
            pulumi.set(__self__, "coupon_id", coupon_id)
        if duration is not None:
            pulumi.set(__self__, "duration", duration)
        if pay_type is not None:
            pulumi.set(__self__, "pay_type", pay_type)
        if quantity is not None:
            pulumi.set(__self__, "quantity", quantity)

    @property
    @pulumi.getter(name="packageVersion")
    def package_version(self) -> pulumi.Input[str]:
        """
        The package version of the market product.
        """
        return pulumi.get(self, "package_version")

    @package_version.setter
    def package_version(self, value: pulumi.Input[str]):
        pulumi.set(self, "package_version", value)

    @property
    @pulumi.getter(name="pricingCycle")
    def pricing_cycle(self) -> pulumi.Input[str]:
        """
        The purchase cycle of the product, valid values are `Day`, `Month` and `Year`.
        """
        return pulumi.get(self, "pricing_cycle")

    @pricing_cycle.setter
    def pricing_cycle(self, value: pulumi.Input[str]):
        pulumi.set(self, "pricing_cycle", value)

    @property
    @pulumi.getter(name="productCode")
    def product_code(self) -> pulumi.Input[str]:
        """
        The product_code of market place product.
        """
        return pulumi.get(self, "product_code")

    @product_code.setter
    def product_code(self, value: pulumi.Input[str]):
        pulumi.set(self, "product_code", value)

    @property
    @pulumi.getter
    def components(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        Service providers customize additional components.
        """
        return pulumi.get(self, "components")

    @components.setter
    def components(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "components", value)

    @property
    @pulumi.getter(name="couponId")
    def coupon_id(self) -> Optional[pulumi.Input[str]]:
        """
        The coupon id of the market product.
        """
        return pulumi.get(self, "coupon_id")

    @coupon_id.setter
    def coupon_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "coupon_id", value)

    @property
    @pulumi.getter
    def duration(self) -> Optional[pulumi.Input[int]]:
        """
        The number of purchase cycles.
        """
        return pulumi.get(self, "duration")

    @duration.setter
    def duration(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "duration", value)

    @property
    @pulumi.getter(name="payType")
    def pay_type(self) -> Optional[pulumi.Input[str]]:
        """
        Valid values are `PrePaid`, `PostPaid`,System default to `PostPaid`.
        """
        return pulumi.get(self, "pay_type")

    @pay_type.setter
    def pay_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "pay_type", value)

    @property
    @pulumi.getter
    def quantity(self) -> Optional[pulumi.Input[int]]:
        """
        The quantity of the market product will be purchased.
        """
        return pulumi.get(self, "quantity")

    @quantity.setter
    def quantity(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "quantity", value)


@pulumi.input_type
class _OrderState:
    def __init__(__self__, *,
                 components: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 coupon_id: Optional[pulumi.Input[str]] = None,
                 duration: Optional[pulumi.Input[int]] = None,
                 package_version: Optional[pulumi.Input[str]] = None,
                 pay_type: Optional[pulumi.Input[str]] = None,
                 pricing_cycle: Optional[pulumi.Input[str]] = None,
                 product_code: Optional[pulumi.Input[str]] = None,
                 quantity: Optional[pulumi.Input[int]] = None):
        """
        Input properties used for looking up and filtering Order resources.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] components: Service providers customize additional components.
        :param pulumi.Input[str] coupon_id: The coupon id of the market product.
        :param pulumi.Input[int] duration: The number of purchase cycles.
        :param pulumi.Input[str] package_version: The package version of the market product.
        :param pulumi.Input[str] pay_type: Valid values are `PrePaid`, `PostPaid`,System default to `PostPaid`.
        :param pulumi.Input[str] pricing_cycle: The purchase cycle of the product, valid values are `Day`, `Month` and `Year`.
        :param pulumi.Input[str] product_code: The product_code of market place product.
        :param pulumi.Input[int] quantity: The quantity of the market product will be purchased.
        """
        if components is not None:
            pulumi.set(__self__, "components", components)
        if coupon_id is not None:
            pulumi.set(__self__, "coupon_id", coupon_id)
        if duration is not None:
            pulumi.set(__self__, "duration", duration)
        if package_version is not None:
            pulumi.set(__self__, "package_version", package_version)
        if pay_type is not None:
            pulumi.set(__self__, "pay_type", pay_type)
        if pricing_cycle is not None:
            pulumi.set(__self__, "pricing_cycle", pricing_cycle)
        if product_code is not None:
            pulumi.set(__self__, "product_code", product_code)
        if quantity is not None:
            pulumi.set(__self__, "quantity", quantity)

    @property
    @pulumi.getter
    def components(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        Service providers customize additional components.
        """
        return pulumi.get(self, "components")

    @components.setter
    def components(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "components", value)

    @property
    @pulumi.getter(name="couponId")
    def coupon_id(self) -> Optional[pulumi.Input[str]]:
        """
        The coupon id of the market product.
        """
        return pulumi.get(self, "coupon_id")

    @coupon_id.setter
    def coupon_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "coupon_id", value)

    @property
    @pulumi.getter
    def duration(self) -> Optional[pulumi.Input[int]]:
        """
        The number of purchase cycles.
        """
        return pulumi.get(self, "duration")

    @duration.setter
    def duration(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "duration", value)

    @property
    @pulumi.getter(name="packageVersion")
    def package_version(self) -> Optional[pulumi.Input[str]]:
        """
        The package version of the market product.
        """
        return pulumi.get(self, "package_version")

    @package_version.setter
    def package_version(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "package_version", value)

    @property
    @pulumi.getter(name="payType")
    def pay_type(self) -> Optional[pulumi.Input[str]]:
        """
        Valid values are `PrePaid`, `PostPaid`,System default to `PostPaid`.
        """
        return pulumi.get(self, "pay_type")

    @pay_type.setter
    def pay_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "pay_type", value)

    @property
    @pulumi.getter(name="pricingCycle")
    def pricing_cycle(self) -> Optional[pulumi.Input[str]]:
        """
        The purchase cycle of the product, valid values are `Day`, `Month` and `Year`.
        """
        return pulumi.get(self, "pricing_cycle")

    @pricing_cycle.setter
    def pricing_cycle(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "pricing_cycle", value)

    @property
    @pulumi.getter(name="productCode")
    def product_code(self) -> Optional[pulumi.Input[str]]:
        """
        The product_code of market place product.
        """
        return pulumi.get(self, "product_code")

    @product_code.setter
    def product_code(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "product_code", value)

    @property
    @pulumi.getter
    def quantity(self) -> Optional[pulumi.Input[int]]:
        """
        The quantity of the market product will be purchased.
        """
        return pulumi.get(self, "quantity")

    @quantity.setter
    def quantity(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "quantity", value)


class Order(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 components: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 coupon_id: Optional[pulumi.Input[str]] = None,
                 duration: Optional[pulumi.Input[int]] = None,
                 package_version: Optional[pulumi.Input[str]] = None,
                 pay_type: Optional[pulumi.Input[str]] = None,
                 pricing_cycle: Optional[pulumi.Input[str]] = None,
                 product_code: Optional[pulumi.Input[str]] = None,
                 quantity: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        """
        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        order = alicloud.marketplace.Order("order",
            product_code="cmapi033136",
            pay_type="prepay",
            quantity=1,
            duration=1,
            pricing_cycle="Month",
            package_version="yuncode2713600001",
            coupon_id="")
        ```

        ## Import

        Market order can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:marketplace/order:Order order your-order-id
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] components: Service providers customize additional components.
        :param pulumi.Input[str] coupon_id: The coupon id of the market product.
        :param pulumi.Input[int] duration: The number of purchase cycles.
        :param pulumi.Input[str] package_version: The package version of the market product.
        :param pulumi.Input[str] pay_type: Valid values are `PrePaid`, `PostPaid`,System default to `PostPaid`.
        :param pulumi.Input[str] pricing_cycle: The purchase cycle of the product, valid values are `Day`, `Month` and `Year`.
        :param pulumi.Input[str] product_code: The product_code of market place product.
        :param pulumi.Input[int] quantity: The quantity of the market product will be purchased.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: OrderArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        order = alicloud.marketplace.Order("order",
            product_code="cmapi033136",
            pay_type="prepay",
            quantity=1,
            duration=1,
            pricing_cycle="Month",
            package_version="yuncode2713600001",
            coupon_id="")
        ```

        ## Import

        Market order can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:marketplace/order:Order order your-order-id
        ```

        :param str resource_name: The name of the resource.
        :param OrderArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(OrderArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 components: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 coupon_id: Optional[pulumi.Input[str]] = None,
                 duration: Optional[pulumi.Input[int]] = None,
                 package_version: Optional[pulumi.Input[str]] = None,
                 pay_type: Optional[pulumi.Input[str]] = None,
                 pricing_cycle: Optional[pulumi.Input[str]] = None,
                 product_code: Optional[pulumi.Input[str]] = None,
                 quantity: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = OrderArgs.__new__(OrderArgs)

            __props__.__dict__["components"] = components
            __props__.__dict__["coupon_id"] = coupon_id
            __props__.__dict__["duration"] = duration
            if package_version is None and not opts.urn:
                raise TypeError("Missing required property 'package_version'")
            __props__.__dict__["package_version"] = package_version
            __props__.__dict__["pay_type"] = pay_type
            if pricing_cycle is None and not opts.urn:
                raise TypeError("Missing required property 'pricing_cycle'")
            __props__.__dict__["pricing_cycle"] = pricing_cycle
            if product_code is None and not opts.urn:
                raise TypeError("Missing required property 'product_code'")
            __props__.__dict__["product_code"] = product_code
            __props__.__dict__["quantity"] = quantity
        super(Order, __self__).__init__(
            'alicloud:marketplace/order:Order',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            components: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            coupon_id: Optional[pulumi.Input[str]] = None,
            duration: Optional[pulumi.Input[int]] = None,
            package_version: Optional[pulumi.Input[str]] = None,
            pay_type: Optional[pulumi.Input[str]] = None,
            pricing_cycle: Optional[pulumi.Input[str]] = None,
            product_code: Optional[pulumi.Input[str]] = None,
            quantity: Optional[pulumi.Input[int]] = None) -> 'Order':
        """
        Get an existing Order resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] components: Service providers customize additional components.
        :param pulumi.Input[str] coupon_id: The coupon id of the market product.
        :param pulumi.Input[int] duration: The number of purchase cycles.
        :param pulumi.Input[str] package_version: The package version of the market product.
        :param pulumi.Input[str] pay_type: Valid values are `PrePaid`, `PostPaid`,System default to `PostPaid`.
        :param pulumi.Input[str] pricing_cycle: The purchase cycle of the product, valid values are `Day`, `Month` and `Year`.
        :param pulumi.Input[str] product_code: The product_code of market place product.
        :param pulumi.Input[int] quantity: The quantity of the market product will be purchased.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _OrderState.__new__(_OrderState)

        __props__.__dict__["components"] = components
        __props__.__dict__["coupon_id"] = coupon_id
        __props__.__dict__["duration"] = duration
        __props__.__dict__["package_version"] = package_version
        __props__.__dict__["pay_type"] = pay_type
        __props__.__dict__["pricing_cycle"] = pricing_cycle
        __props__.__dict__["product_code"] = product_code
        __props__.__dict__["quantity"] = quantity
        return Order(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def components(self) -> pulumi.Output[Optional[Mapping[str, str]]]:
        """
        Service providers customize additional components.
        """
        return pulumi.get(self, "components")

    @property
    @pulumi.getter(name="couponId")
    def coupon_id(self) -> pulumi.Output[Optional[str]]:
        """
        The coupon id of the market product.
        """
        return pulumi.get(self, "coupon_id")

    @property
    @pulumi.getter
    def duration(self) -> pulumi.Output[Optional[int]]:
        """
        The number of purchase cycles.
        """
        return pulumi.get(self, "duration")

    @property
    @pulumi.getter(name="packageVersion")
    def package_version(self) -> pulumi.Output[str]:
        """
        The package version of the market product.
        """
        return pulumi.get(self, "package_version")

    @property
    @pulumi.getter(name="payType")
    def pay_type(self) -> pulumi.Output[Optional[str]]:
        """
        Valid values are `PrePaid`, `PostPaid`,System default to `PostPaid`.
        """
        return pulumi.get(self, "pay_type")

    @property
    @pulumi.getter(name="pricingCycle")
    def pricing_cycle(self) -> pulumi.Output[str]:
        """
        The purchase cycle of the product, valid values are `Day`, `Month` and `Year`.
        """
        return pulumi.get(self, "pricing_cycle")

    @property
    @pulumi.getter(name="productCode")
    def product_code(self) -> pulumi.Output[str]:
        """
        The product_code of market place product.
        """
        return pulumi.get(self, "product_code")

    @property
    @pulumi.getter
    def quantity(self) -> pulumi.Output[Optional[int]]:
        """
        The quantity of the market product will be purchased.
        """
        return pulumi.get(self, "quantity")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['EcdPolicyGroupArgs', 'EcdPolicyGroup']

@pulumi.input_type
class EcdPolicyGroupArgs:
    def __init__(__self__, *,
                 authorize_access_policy_rules: Optional[pulumi.Input[Sequence[pulumi.Input['EcdPolicyGroupAuthorizeAccessPolicyRuleArgs']]]] = None,
                 authorize_security_policy_rules: Optional[pulumi.Input[Sequence[pulumi.Input['EcdPolicyGroupAuthorizeSecurityPolicyRuleArgs']]]] = None,
                 camera_redirect: Optional[pulumi.Input[str]] = None,
                 clipboard: Optional[pulumi.Input[str]] = None,
                 domain_list: Optional[pulumi.Input[str]] = None,
                 html_access: Optional[pulumi.Input[str]] = None,
                 html_file_transfer: Optional[pulumi.Input[str]] = None,
                 local_drive: Optional[pulumi.Input[str]] = None,
                 policy_group_name: Optional[pulumi.Input[str]] = None,
                 recording: Optional[pulumi.Input[str]] = None,
                 recording_end_time: Optional[pulumi.Input[str]] = None,
                 recording_expires: Optional[pulumi.Input[int]] = None,
                 recording_fps: Optional[pulumi.Input[int]] = None,
                 recording_start_time: Optional[pulumi.Input[str]] = None,
                 usb_redirect: Optional[pulumi.Input[str]] = None,
                 visual_quality: Optional[pulumi.Input[str]] = None,
                 watermark: Optional[pulumi.Input[str]] = None,
                 watermark_transparency: Optional[pulumi.Input[str]] = None,
                 watermark_type: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a EcdPolicyGroup resource.
        :param pulumi.Input[Sequence[pulumi.Input['EcdPolicyGroupAuthorizeAccessPolicyRuleArgs']]] authorize_access_policy_rules: The rule of authorize access rule. See `authorize_access_policy_rules` below.
        :param pulumi.Input[Sequence[pulumi.Input['EcdPolicyGroupAuthorizeSecurityPolicyRuleArgs']]] authorize_security_policy_rules: The policy rule. See `authorize_security_policy_rules` below.
        :param pulumi.Input[str] camera_redirect: Whether to enable local camera redirection. Valid values: `on`, `off`.
        :param pulumi.Input[str] clipboard: The clipboard policy. Valid values: `off`, `read`, `readwrite`.
        :param pulumi.Input[str] domain_list: The list of domain.
        :param pulumi.Input[str] html_access: The access of html5. Valid values: `off`, `on`.
        :param pulumi.Input[str] html_file_transfer: The html5 file transfer. Valid values: `all`, `download`, `off`, `upload`.
        :param pulumi.Input[str] local_drive: Local drive redirect policy. Valid values: ` readwrite`, `off`, `read`.
        :param pulumi.Input[str] policy_group_name: The name of policy group.
        :param pulumi.Input[str] recording: Whether to enable screen recording. Valid values: `off`, `all-time`, `period`.
        :param pulumi.Input[str] recording_end_time: The end time of recording, value: `HH:MM:SS`. This return value is meaningful only when the value of `recording` is `period`.
        :param pulumi.Input[int] recording_expires: The screen recording video retention. Valid values between 30 and 180. This return value is meaningful only when the value of `recording` is `period` or `all-time`.
        :param pulumi.Input[int] recording_fps: The fps of recording. Valid values: `2`, `5`, `10`, `15`.
        :param pulumi.Input[str] recording_start_time: The start time of recording, value: `HH:MM:SS`. This return value is meaningful only when the value of `recording` is `period`.
        :param pulumi.Input[str] usb_redirect: The usb redirect policy. Valid values: `off`, `on`.
        :param pulumi.Input[str] visual_quality: The quality of visual. Valid values: `high`, `lossless`, `low`, `medium`.
        :param pulumi.Input[str] watermark: The watermark policy. Valid values: `off`, `on`.
        :param pulumi.Input[str] watermark_transparency: The watermark transparency. Valid values: `DARK`, `LIGHT`, `MIDDLE`.
        :param pulumi.Input[str] watermark_type: The type of watemark. Valid values: `EndUserId`, `HostName`.
        """
        if authorize_access_policy_rules is not None:
            pulumi.set(__self__, "authorize_access_policy_rules", authorize_access_policy_rules)
        if authorize_security_policy_rules is not None:
            pulumi.set(__self__, "authorize_security_policy_rules", authorize_security_policy_rules)
        if camera_redirect is not None:
            pulumi.set(__self__, "camera_redirect", camera_redirect)
        if clipboard is not None:
            pulumi.set(__self__, "clipboard", clipboard)
        if domain_list is not None:
            pulumi.set(__self__, "domain_list", domain_list)
        if html_access is not None:
            pulumi.set(__self__, "html_access", html_access)
        if html_file_transfer is not None:
            pulumi.set(__self__, "html_file_transfer", html_file_transfer)
        if local_drive is not None:
            pulumi.set(__self__, "local_drive", local_drive)
        if policy_group_name is not None:
            pulumi.set(__self__, "policy_group_name", policy_group_name)
        if recording is not None:
            pulumi.set(__self__, "recording", recording)
        if recording_end_time is not None:
            pulumi.set(__self__, "recording_end_time", recording_end_time)
        if recording_expires is not None:
            pulumi.set(__self__, "recording_expires", recording_expires)
        if recording_fps is not None:
            pulumi.set(__self__, "recording_fps", recording_fps)
        if recording_start_time is not None:
            pulumi.set(__self__, "recording_start_time", recording_start_time)
        if usb_redirect is not None:
            pulumi.set(__self__, "usb_redirect", usb_redirect)
        if visual_quality is not None:
            pulumi.set(__self__, "visual_quality", visual_quality)
        if watermark is not None:
            pulumi.set(__self__, "watermark", watermark)
        if watermark_transparency is not None:
            pulumi.set(__self__, "watermark_transparency", watermark_transparency)
        if watermark_type is not None:
            pulumi.set(__self__, "watermark_type", watermark_type)

    @property
    @pulumi.getter(name="authorizeAccessPolicyRules")
    def authorize_access_policy_rules(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['EcdPolicyGroupAuthorizeAccessPolicyRuleArgs']]]]:
        """
        The rule of authorize access rule. See `authorize_access_policy_rules` below.
        """
        return pulumi.get(self, "authorize_access_policy_rules")

    @authorize_access_policy_rules.setter
    def authorize_access_policy_rules(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['EcdPolicyGroupAuthorizeAccessPolicyRuleArgs']]]]):
        pulumi.set(self, "authorize_access_policy_rules", value)

    @property
    @pulumi.getter(name="authorizeSecurityPolicyRules")
    def authorize_security_policy_rules(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['EcdPolicyGroupAuthorizeSecurityPolicyRuleArgs']]]]:
        """
        The policy rule. See `authorize_security_policy_rules` below.
        """
        return pulumi.get(self, "authorize_security_policy_rules")

    @authorize_security_policy_rules.setter
    def authorize_security_policy_rules(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['EcdPolicyGroupAuthorizeSecurityPolicyRuleArgs']]]]):
        pulumi.set(self, "authorize_security_policy_rules", value)

    @property
    @pulumi.getter(name="cameraRedirect")
    def camera_redirect(self) -> Optional[pulumi.Input[str]]:
        """
        Whether to enable local camera redirection. Valid values: `on`, `off`.
        """
        return pulumi.get(self, "camera_redirect")

    @camera_redirect.setter
    def camera_redirect(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "camera_redirect", value)

    @property
    @pulumi.getter
    def clipboard(self) -> Optional[pulumi.Input[str]]:
        """
        The clipboard policy. Valid values: `off`, `read`, `readwrite`.
        """
        return pulumi.get(self, "clipboard")

    @clipboard.setter
    def clipboard(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "clipboard", value)

    @property
    @pulumi.getter(name="domainList")
    def domain_list(self) -> Optional[pulumi.Input[str]]:
        """
        The list of domain.
        """
        return pulumi.get(self, "domain_list")

    @domain_list.setter
    def domain_list(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "domain_list", value)

    @property
    @pulumi.getter(name="htmlAccess")
    def html_access(self) -> Optional[pulumi.Input[str]]:
        """
        The access of html5. Valid values: `off`, `on`.
        """
        return pulumi.get(self, "html_access")

    @html_access.setter
    def html_access(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "html_access", value)

    @property
    @pulumi.getter(name="htmlFileTransfer")
    def html_file_transfer(self) -> Optional[pulumi.Input[str]]:
        """
        The html5 file transfer. Valid values: `all`, `download`, `off`, `upload`.
        """
        return pulumi.get(self, "html_file_transfer")

    @html_file_transfer.setter
    def html_file_transfer(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "html_file_transfer", value)

    @property
    @pulumi.getter(name="localDrive")
    def local_drive(self) -> Optional[pulumi.Input[str]]:
        """
        Local drive redirect policy. Valid values: ` readwrite`, `off`, `read`.
        """
        return pulumi.get(self, "local_drive")

    @local_drive.setter
    def local_drive(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "local_drive", value)

    @property
    @pulumi.getter(name="policyGroupName")
    def policy_group_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of policy group.
        """
        return pulumi.get(self, "policy_group_name")

    @policy_group_name.setter
    def policy_group_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "policy_group_name", value)

    @property
    @pulumi.getter
    def recording(self) -> Optional[pulumi.Input[str]]:
        """
        Whether to enable screen recording. Valid values: `off`, `all-time`, `period`.
        """
        return pulumi.get(self, "recording")

    @recording.setter
    def recording(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "recording", value)

    @property
    @pulumi.getter(name="recordingEndTime")
    def recording_end_time(self) -> Optional[pulumi.Input[str]]:
        """
        The end time of recording, value: `HH:MM:SS`. This return value is meaningful only when the value of `recording` is `period`.
        """
        return pulumi.get(self, "recording_end_time")

    @recording_end_time.setter
    def recording_end_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "recording_end_time", value)

    @property
    @pulumi.getter(name="recordingExpires")
    def recording_expires(self) -> Optional[pulumi.Input[int]]:
        """
        The screen recording video retention. Valid values between 30 and 180. This return value is meaningful only when the value of `recording` is `period` or `all-time`.
        """
        return pulumi.get(self, "recording_expires")

    @recording_expires.setter
    def recording_expires(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "recording_expires", value)

    @property
    @pulumi.getter(name="recordingFps")
    def recording_fps(self) -> Optional[pulumi.Input[int]]:
        """
        The fps of recording. Valid values: `2`, `5`, `10`, `15`.
        """
        return pulumi.get(self, "recording_fps")

    @recording_fps.setter
    def recording_fps(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "recording_fps", value)

    @property
    @pulumi.getter(name="recordingStartTime")
    def recording_start_time(self) -> Optional[pulumi.Input[str]]:
        """
        The start time of recording, value: `HH:MM:SS`. This return value is meaningful only when the value of `recording` is `period`.
        """
        return pulumi.get(self, "recording_start_time")

    @recording_start_time.setter
    def recording_start_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "recording_start_time", value)

    @property
    @pulumi.getter(name="usbRedirect")
    def usb_redirect(self) -> Optional[pulumi.Input[str]]:
        """
        The usb redirect policy. Valid values: `off`, `on`.
        """
        return pulumi.get(self, "usb_redirect")

    @usb_redirect.setter
    def usb_redirect(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "usb_redirect", value)

    @property
    @pulumi.getter(name="visualQuality")
    def visual_quality(self) -> Optional[pulumi.Input[str]]:
        """
        The quality of visual. Valid values: `high`, `lossless`, `low`, `medium`.
        """
        return pulumi.get(self, "visual_quality")

    @visual_quality.setter
    def visual_quality(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "visual_quality", value)

    @property
    @pulumi.getter
    def watermark(self) -> Optional[pulumi.Input[str]]:
        """
        The watermark policy. Valid values: `off`, `on`.
        """
        return pulumi.get(self, "watermark")

    @watermark.setter
    def watermark(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "watermark", value)

    @property
    @pulumi.getter(name="watermarkTransparency")
    def watermark_transparency(self) -> Optional[pulumi.Input[str]]:
        """
        The watermark transparency. Valid values: `DARK`, `LIGHT`, `MIDDLE`.
        """
        return pulumi.get(self, "watermark_transparency")

    @watermark_transparency.setter
    def watermark_transparency(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "watermark_transparency", value)

    @property
    @pulumi.getter(name="watermarkType")
    def watermark_type(self) -> Optional[pulumi.Input[str]]:
        """
        The type of watemark. Valid values: `EndUserId`, `HostName`.
        """
        return pulumi.get(self, "watermark_type")

    @watermark_type.setter
    def watermark_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "watermark_type", value)


@pulumi.input_type
class _EcdPolicyGroupState:
    def __init__(__self__, *,
                 authorize_access_policy_rules: Optional[pulumi.Input[Sequence[pulumi.Input['EcdPolicyGroupAuthorizeAccessPolicyRuleArgs']]]] = None,
                 authorize_security_policy_rules: Optional[pulumi.Input[Sequence[pulumi.Input['EcdPolicyGroupAuthorizeSecurityPolicyRuleArgs']]]] = None,
                 camera_redirect: Optional[pulumi.Input[str]] = None,
                 clipboard: Optional[pulumi.Input[str]] = None,
                 domain_list: Optional[pulumi.Input[str]] = None,
                 html_access: Optional[pulumi.Input[str]] = None,
                 html_file_transfer: Optional[pulumi.Input[str]] = None,
                 local_drive: Optional[pulumi.Input[str]] = None,
                 policy_group_name: Optional[pulumi.Input[str]] = None,
                 recording: Optional[pulumi.Input[str]] = None,
                 recording_end_time: Optional[pulumi.Input[str]] = None,
                 recording_expires: Optional[pulumi.Input[int]] = None,
                 recording_fps: Optional[pulumi.Input[int]] = None,
                 recording_start_time: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 usb_redirect: Optional[pulumi.Input[str]] = None,
                 visual_quality: Optional[pulumi.Input[str]] = None,
                 watermark: Optional[pulumi.Input[str]] = None,
                 watermark_transparency: Optional[pulumi.Input[str]] = None,
                 watermark_type: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering EcdPolicyGroup resources.
        :param pulumi.Input[Sequence[pulumi.Input['EcdPolicyGroupAuthorizeAccessPolicyRuleArgs']]] authorize_access_policy_rules: The rule of authorize access rule. See `authorize_access_policy_rules` below.
        :param pulumi.Input[Sequence[pulumi.Input['EcdPolicyGroupAuthorizeSecurityPolicyRuleArgs']]] authorize_security_policy_rules: The policy rule. See `authorize_security_policy_rules` below.
        :param pulumi.Input[str] camera_redirect: Whether to enable local camera redirection. Valid values: `on`, `off`.
        :param pulumi.Input[str] clipboard: The clipboard policy. Valid values: `off`, `read`, `readwrite`.
        :param pulumi.Input[str] domain_list: The list of domain.
        :param pulumi.Input[str] html_access: The access of html5. Valid values: `off`, `on`.
        :param pulumi.Input[str] html_file_transfer: The html5 file transfer. Valid values: `all`, `download`, `off`, `upload`.
        :param pulumi.Input[str] local_drive: Local drive redirect policy. Valid values: ` readwrite`, `off`, `read`.
        :param pulumi.Input[str] policy_group_name: The name of policy group.
        :param pulumi.Input[str] recording: Whether to enable screen recording. Valid values: `off`, `all-time`, `period`.
        :param pulumi.Input[str] recording_end_time: The end time of recording, value: `HH:MM:SS`. This return value is meaningful only when the value of `recording` is `period`.
        :param pulumi.Input[int] recording_expires: The screen recording video retention. Valid values between 30 and 180. This return value is meaningful only when the value of `recording` is `period` or `all-time`.
        :param pulumi.Input[int] recording_fps: The fps of recording. Valid values: `2`, `5`, `10`, `15`.
        :param pulumi.Input[str] recording_start_time: The start time of recording, value: `HH:MM:SS`. This return value is meaningful only when the value of `recording` is `period`.
        :param pulumi.Input[str] status: The status of policy.
        :param pulumi.Input[str] usb_redirect: The usb redirect policy. Valid values: `off`, `on`.
        :param pulumi.Input[str] visual_quality: The quality of visual. Valid values: `high`, `lossless`, `low`, `medium`.
        :param pulumi.Input[str] watermark: The watermark policy. Valid values: `off`, `on`.
        :param pulumi.Input[str] watermark_transparency: The watermark transparency. Valid values: `DARK`, `LIGHT`, `MIDDLE`.
        :param pulumi.Input[str] watermark_type: The type of watemark. Valid values: `EndUserId`, `HostName`.
        """
        if authorize_access_policy_rules is not None:
            pulumi.set(__self__, "authorize_access_policy_rules", authorize_access_policy_rules)
        if authorize_security_policy_rules is not None:
            pulumi.set(__self__, "authorize_security_policy_rules", authorize_security_policy_rules)
        if camera_redirect is not None:
            pulumi.set(__self__, "camera_redirect", camera_redirect)
        if clipboard is not None:
            pulumi.set(__self__, "clipboard", clipboard)
        if domain_list is not None:
            pulumi.set(__self__, "domain_list", domain_list)
        if html_access is not None:
            pulumi.set(__self__, "html_access", html_access)
        if html_file_transfer is not None:
            pulumi.set(__self__, "html_file_transfer", html_file_transfer)
        if local_drive is not None:
            pulumi.set(__self__, "local_drive", local_drive)
        if policy_group_name is not None:
            pulumi.set(__self__, "policy_group_name", policy_group_name)
        if recording is not None:
            pulumi.set(__self__, "recording", recording)
        if recording_end_time is not None:
            pulumi.set(__self__, "recording_end_time", recording_end_time)
        if recording_expires is not None:
            pulumi.set(__self__, "recording_expires", recording_expires)
        if recording_fps is not None:
            pulumi.set(__self__, "recording_fps", recording_fps)
        if recording_start_time is not None:
            pulumi.set(__self__, "recording_start_time", recording_start_time)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if usb_redirect is not None:
            pulumi.set(__self__, "usb_redirect", usb_redirect)
        if visual_quality is not None:
            pulumi.set(__self__, "visual_quality", visual_quality)
        if watermark is not None:
            pulumi.set(__self__, "watermark", watermark)
        if watermark_transparency is not None:
            pulumi.set(__self__, "watermark_transparency", watermark_transparency)
        if watermark_type is not None:
            pulumi.set(__self__, "watermark_type", watermark_type)

    @property
    @pulumi.getter(name="authorizeAccessPolicyRules")
    def authorize_access_policy_rules(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['EcdPolicyGroupAuthorizeAccessPolicyRuleArgs']]]]:
        """
        The rule of authorize access rule. See `authorize_access_policy_rules` below.
        """
        return pulumi.get(self, "authorize_access_policy_rules")

    @authorize_access_policy_rules.setter
    def authorize_access_policy_rules(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['EcdPolicyGroupAuthorizeAccessPolicyRuleArgs']]]]):
        pulumi.set(self, "authorize_access_policy_rules", value)

    @property
    @pulumi.getter(name="authorizeSecurityPolicyRules")
    def authorize_security_policy_rules(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['EcdPolicyGroupAuthorizeSecurityPolicyRuleArgs']]]]:
        """
        The policy rule. See `authorize_security_policy_rules` below.
        """
        return pulumi.get(self, "authorize_security_policy_rules")

    @authorize_security_policy_rules.setter
    def authorize_security_policy_rules(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['EcdPolicyGroupAuthorizeSecurityPolicyRuleArgs']]]]):
        pulumi.set(self, "authorize_security_policy_rules", value)

    @property
    @pulumi.getter(name="cameraRedirect")
    def camera_redirect(self) -> Optional[pulumi.Input[str]]:
        """
        Whether to enable local camera redirection. Valid values: `on`, `off`.
        """
        return pulumi.get(self, "camera_redirect")

    @camera_redirect.setter
    def camera_redirect(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "camera_redirect", value)

    @property
    @pulumi.getter
    def clipboard(self) -> Optional[pulumi.Input[str]]:
        """
        The clipboard policy. Valid values: `off`, `read`, `readwrite`.
        """
        return pulumi.get(self, "clipboard")

    @clipboard.setter
    def clipboard(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "clipboard", value)

    @property
    @pulumi.getter(name="domainList")
    def domain_list(self) -> Optional[pulumi.Input[str]]:
        """
        The list of domain.
        """
        return pulumi.get(self, "domain_list")

    @domain_list.setter
    def domain_list(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "domain_list", value)

    @property
    @pulumi.getter(name="htmlAccess")
    def html_access(self) -> Optional[pulumi.Input[str]]:
        """
        The access of html5. Valid values: `off`, `on`.
        """
        return pulumi.get(self, "html_access")

    @html_access.setter
    def html_access(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "html_access", value)

    @property
    @pulumi.getter(name="htmlFileTransfer")
    def html_file_transfer(self) -> Optional[pulumi.Input[str]]:
        """
        The html5 file transfer. Valid values: `all`, `download`, `off`, `upload`.
        """
        return pulumi.get(self, "html_file_transfer")

    @html_file_transfer.setter
    def html_file_transfer(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "html_file_transfer", value)

    @property
    @pulumi.getter(name="localDrive")
    def local_drive(self) -> Optional[pulumi.Input[str]]:
        """
        Local drive redirect policy. Valid values: ` readwrite`, `off`, `read`.
        """
        return pulumi.get(self, "local_drive")

    @local_drive.setter
    def local_drive(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "local_drive", value)

    @property
    @pulumi.getter(name="policyGroupName")
    def policy_group_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of policy group.
        """
        return pulumi.get(self, "policy_group_name")

    @policy_group_name.setter
    def policy_group_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "policy_group_name", value)

    @property
    @pulumi.getter
    def recording(self) -> Optional[pulumi.Input[str]]:
        """
        Whether to enable screen recording. Valid values: `off`, `all-time`, `period`.
        """
        return pulumi.get(self, "recording")

    @recording.setter
    def recording(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "recording", value)

    @property
    @pulumi.getter(name="recordingEndTime")
    def recording_end_time(self) -> Optional[pulumi.Input[str]]:
        """
        The end time of recording, value: `HH:MM:SS`. This return value is meaningful only when the value of `recording` is `period`.
        """
        return pulumi.get(self, "recording_end_time")

    @recording_end_time.setter
    def recording_end_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "recording_end_time", value)

    @property
    @pulumi.getter(name="recordingExpires")
    def recording_expires(self) -> Optional[pulumi.Input[int]]:
        """
        The screen recording video retention. Valid values between 30 and 180. This return value is meaningful only when the value of `recording` is `period` or `all-time`.
        """
        return pulumi.get(self, "recording_expires")

    @recording_expires.setter
    def recording_expires(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "recording_expires", value)

    @property
    @pulumi.getter(name="recordingFps")
    def recording_fps(self) -> Optional[pulumi.Input[int]]:
        """
        The fps of recording. Valid values: `2`, `5`, `10`, `15`.
        """
        return pulumi.get(self, "recording_fps")

    @recording_fps.setter
    def recording_fps(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "recording_fps", value)

    @property
    @pulumi.getter(name="recordingStartTime")
    def recording_start_time(self) -> Optional[pulumi.Input[str]]:
        """
        The start time of recording, value: `HH:MM:SS`. This return value is meaningful only when the value of `recording` is `period`.
        """
        return pulumi.get(self, "recording_start_time")

    @recording_start_time.setter
    def recording_start_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "recording_start_time", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The status of policy.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="usbRedirect")
    def usb_redirect(self) -> Optional[pulumi.Input[str]]:
        """
        The usb redirect policy. Valid values: `off`, `on`.
        """
        return pulumi.get(self, "usb_redirect")

    @usb_redirect.setter
    def usb_redirect(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "usb_redirect", value)

    @property
    @pulumi.getter(name="visualQuality")
    def visual_quality(self) -> Optional[pulumi.Input[str]]:
        """
        The quality of visual. Valid values: `high`, `lossless`, `low`, `medium`.
        """
        return pulumi.get(self, "visual_quality")

    @visual_quality.setter
    def visual_quality(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "visual_quality", value)

    @property
    @pulumi.getter
    def watermark(self) -> Optional[pulumi.Input[str]]:
        """
        The watermark policy. Valid values: `off`, `on`.
        """
        return pulumi.get(self, "watermark")

    @watermark.setter
    def watermark(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "watermark", value)

    @property
    @pulumi.getter(name="watermarkTransparency")
    def watermark_transparency(self) -> Optional[pulumi.Input[str]]:
        """
        The watermark transparency. Valid values: `DARK`, `LIGHT`, `MIDDLE`.
        """
        return pulumi.get(self, "watermark_transparency")

    @watermark_transparency.setter
    def watermark_transparency(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "watermark_transparency", value)

    @property
    @pulumi.getter(name="watermarkType")
    def watermark_type(self) -> Optional[pulumi.Input[str]]:
        """
        The type of watemark. Valid values: `EndUserId`, `HostName`.
        """
        return pulumi.get(self, "watermark_type")

    @watermark_type.setter
    def watermark_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "watermark_type", value)


class EcdPolicyGroup(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 authorize_access_policy_rules: Optional[pulumi.Input[Sequence[pulumi.Input[Union['EcdPolicyGroupAuthorizeAccessPolicyRuleArgs', 'EcdPolicyGroupAuthorizeAccessPolicyRuleArgsDict']]]]] = None,
                 authorize_security_policy_rules: Optional[pulumi.Input[Sequence[pulumi.Input[Union['EcdPolicyGroupAuthorizeSecurityPolicyRuleArgs', 'EcdPolicyGroupAuthorizeSecurityPolicyRuleArgsDict']]]]] = None,
                 camera_redirect: Optional[pulumi.Input[str]] = None,
                 clipboard: Optional[pulumi.Input[str]] = None,
                 domain_list: Optional[pulumi.Input[str]] = None,
                 html_access: Optional[pulumi.Input[str]] = None,
                 html_file_transfer: Optional[pulumi.Input[str]] = None,
                 local_drive: Optional[pulumi.Input[str]] = None,
                 policy_group_name: Optional[pulumi.Input[str]] = None,
                 recording: Optional[pulumi.Input[str]] = None,
                 recording_end_time: Optional[pulumi.Input[str]] = None,
                 recording_expires: Optional[pulumi.Input[int]] = None,
                 recording_fps: Optional[pulumi.Input[int]] = None,
                 recording_start_time: Optional[pulumi.Input[str]] = None,
                 usb_redirect: Optional[pulumi.Input[str]] = None,
                 visual_quality: Optional[pulumi.Input[str]] = None,
                 watermark: Optional[pulumi.Input[str]] = None,
                 watermark_transparency: Optional[pulumi.Input[str]] = None,
                 watermark_type: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a Elastic Desktop Service (ECD) Policy Group resource.

        For information about Elastic Desktop Service (ECD) Policy Group and how to use it, see [What is Policy Group](https://www.alibabacloud.com/help/en/wuying-workspace/developer-reference/api-ecd-2020-09-30-createpolicygroup).

        > **NOTE:** Available since v1.130.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default = alicloud.eds.EcdPolicyGroup("default",
            policy_group_name="terraform-example",
            clipboard="read",
            local_drive="read",
            usb_redirect="off",
            watermark="off",
            authorize_access_policy_rules=[{
                "description": "terraform-example",
                "cidr_ip": "1.2.3.45/24",
            }],
            authorize_security_policy_rules=[{
                "type": "inflow",
                "policy": "accept",
                "description": "terraform-example",
                "port_range": "80/80",
                "ip_protocol": "TCP",
                "priority": "1",
                "cidr_ip": "1.2.3.4/24",
            }])
        ```

        ## Import

        Elastic Desktop Service (ECD) Policy Group can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:eds/ecdPolicyGroup:EcdPolicyGroup example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['EcdPolicyGroupAuthorizeAccessPolicyRuleArgs', 'EcdPolicyGroupAuthorizeAccessPolicyRuleArgsDict']]]] authorize_access_policy_rules: The rule of authorize access rule. See `authorize_access_policy_rules` below.
        :param pulumi.Input[Sequence[pulumi.Input[Union['EcdPolicyGroupAuthorizeSecurityPolicyRuleArgs', 'EcdPolicyGroupAuthorizeSecurityPolicyRuleArgsDict']]]] authorize_security_policy_rules: The policy rule. See `authorize_security_policy_rules` below.
        :param pulumi.Input[str] camera_redirect: Whether to enable local camera redirection. Valid values: `on`, `off`.
        :param pulumi.Input[str] clipboard: The clipboard policy. Valid values: `off`, `read`, `readwrite`.
        :param pulumi.Input[str] domain_list: The list of domain.
        :param pulumi.Input[str] html_access: The access of html5. Valid values: `off`, `on`.
        :param pulumi.Input[str] html_file_transfer: The html5 file transfer. Valid values: `all`, `download`, `off`, `upload`.
        :param pulumi.Input[str] local_drive: Local drive redirect policy. Valid values: ` readwrite`, `off`, `read`.
        :param pulumi.Input[str] policy_group_name: The name of policy group.
        :param pulumi.Input[str] recording: Whether to enable screen recording. Valid values: `off`, `all-time`, `period`.
        :param pulumi.Input[str] recording_end_time: The end time of recording, value: `HH:MM:SS`. This return value is meaningful only when the value of `recording` is `period`.
        :param pulumi.Input[int] recording_expires: The screen recording video retention. Valid values between 30 and 180. This return value is meaningful only when the value of `recording` is `period` or `all-time`.
        :param pulumi.Input[int] recording_fps: The fps of recording. Valid values: `2`, `5`, `10`, `15`.
        :param pulumi.Input[str] recording_start_time: The start time of recording, value: `HH:MM:SS`. This return value is meaningful only when the value of `recording` is `period`.
        :param pulumi.Input[str] usb_redirect: The usb redirect policy. Valid values: `off`, `on`.
        :param pulumi.Input[str] visual_quality: The quality of visual. Valid values: `high`, `lossless`, `low`, `medium`.
        :param pulumi.Input[str] watermark: The watermark policy. Valid values: `off`, `on`.
        :param pulumi.Input[str] watermark_transparency: The watermark transparency. Valid values: `DARK`, `LIGHT`, `MIDDLE`.
        :param pulumi.Input[str] watermark_type: The type of watemark. Valid values: `EndUserId`, `HostName`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[EcdPolicyGroupArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Elastic Desktop Service (ECD) Policy Group resource.

        For information about Elastic Desktop Service (ECD) Policy Group and how to use it, see [What is Policy Group](https://www.alibabacloud.com/help/en/wuying-workspace/developer-reference/api-ecd-2020-09-30-createpolicygroup).

        > **NOTE:** Available since v1.130.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default = alicloud.eds.EcdPolicyGroup("default",
            policy_group_name="terraform-example",
            clipboard="read",
            local_drive="read",
            usb_redirect="off",
            watermark="off",
            authorize_access_policy_rules=[{
                "description": "terraform-example",
                "cidr_ip": "1.2.3.45/24",
            }],
            authorize_security_policy_rules=[{
                "type": "inflow",
                "policy": "accept",
                "description": "terraform-example",
                "port_range": "80/80",
                "ip_protocol": "TCP",
                "priority": "1",
                "cidr_ip": "1.2.3.4/24",
            }])
        ```

        ## Import

        Elastic Desktop Service (ECD) Policy Group can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:eds/ecdPolicyGroup:EcdPolicyGroup example <id>
        ```

        :param str resource_name: The name of the resource.
        :param EcdPolicyGroupArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(EcdPolicyGroupArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 authorize_access_policy_rules: Optional[pulumi.Input[Sequence[pulumi.Input[Union['EcdPolicyGroupAuthorizeAccessPolicyRuleArgs', 'EcdPolicyGroupAuthorizeAccessPolicyRuleArgsDict']]]]] = None,
                 authorize_security_policy_rules: Optional[pulumi.Input[Sequence[pulumi.Input[Union['EcdPolicyGroupAuthorizeSecurityPolicyRuleArgs', 'EcdPolicyGroupAuthorizeSecurityPolicyRuleArgsDict']]]]] = None,
                 camera_redirect: Optional[pulumi.Input[str]] = None,
                 clipboard: Optional[pulumi.Input[str]] = None,
                 domain_list: Optional[pulumi.Input[str]] = None,
                 html_access: Optional[pulumi.Input[str]] = None,
                 html_file_transfer: Optional[pulumi.Input[str]] = None,
                 local_drive: Optional[pulumi.Input[str]] = None,
                 policy_group_name: Optional[pulumi.Input[str]] = None,
                 recording: Optional[pulumi.Input[str]] = None,
                 recording_end_time: Optional[pulumi.Input[str]] = None,
                 recording_expires: Optional[pulumi.Input[int]] = None,
                 recording_fps: Optional[pulumi.Input[int]] = None,
                 recording_start_time: Optional[pulumi.Input[str]] = None,
                 usb_redirect: Optional[pulumi.Input[str]] = None,
                 visual_quality: Optional[pulumi.Input[str]] = None,
                 watermark: Optional[pulumi.Input[str]] = None,
                 watermark_transparency: Optional[pulumi.Input[str]] = None,
                 watermark_type: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = EcdPolicyGroupArgs.__new__(EcdPolicyGroupArgs)

            __props__.__dict__["authorize_access_policy_rules"] = authorize_access_policy_rules
            __props__.__dict__["authorize_security_policy_rules"] = authorize_security_policy_rules
            __props__.__dict__["camera_redirect"] = camera_redirect
            __props__.__dict__["clipboard"] = clipboard
            __props__.__dict__["domain_list"] = domain_list
            __props__.__dict__["html_access"] = html_access
            __props__.__dict__["html_file_transfer"] = html_file_transfer
            __props__.__dict__["local_drive"] = local_drive
            __props__.__dict__["policy_group_name"] = policy_group_name
            __props__.__dict__["recording"] = recording
            __props__.__dict__["recording_end_time"] = recording_end_time
            __props__.__dict__["recording_expires"] = recording_expires
            __props__.__dict__["recording_fps"] = recording_fps
            __props__.__dict__["recording_start_time"] = recording_start_time
            __props__.__dict__["usb_redirect"] = usb_redirect
            __props__.__dict__["visual_quality"] = visual_quality
            __props__.__dict__["watermark"] = watermark
            __props__.__dict__["watermark_transparency"] = watermark_transparency
            __props__.__dict__["watermark_type"] = watermark_type
            __props__.__dict__["status"] = None
        super(EcdPolicyGroup, __self__).__init__(
            'alicloud:eds/ecdPolicyGroup:EcdPolicyGroup',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            authorize_access_policy_rules: Optional[pulumi.Input[Sequence[pulumi.Input[Union['EcdPolicyGroupAuthorizeAccessPolicyRuleArgs', 'EcdPolicyGroupAuthorizeAccessPolicyRuleArgsDict']]]]] = None,
            authorize_security_policy_rules: Optional[pulumi.Input[Sequence[pulumi.Input[Union['EcdPolicyGroupAuthorizeSecurityPolicyRuleArgs', 'EcdPolicyGroupAuthorizeSecurityPolicyRuleArgsDict']]]]] = None,
            camera_redirect: Optional[pulumi.Input[str]] = None,
            clipboard: Optional[pulumi.Input[str]] = None,
            domain_list: Optional[pulumi.Input[str]] = None,
            html_access: Optional[pulumi.Input[str]] = None,
            html_file_transfer: Optional[pulumi.Input[str]] = None,
            local_drive: Optional[pulumi.Input[str]] = None,
            policy_group_name: Optional[pulumi.Input[str]] = None,
            recording: Optional[pulumi.Input[str]] = None,
            recording_end_time: Optional[pulumi.Input[str]] = None,
            recording_expires: Optional[pulumi.Input[int]] = None,
            recording_fps: Optional[pulumi.Input[int]] = None,
            recording_start_time: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None,
            usb_redirect: Optional[pulumi.Input[str]] = None,
            visual_quality: Optional[pulumi.Input[str]] = None,
            watermark: Optional[pulumi.Input[str]] = None,
            watermark_transparency: Optional[pulumi.Input[str]] = None,
            watermark_type: Optional[pulumi.Input[str]] = None) -> 'EcdPolicyGroup':
        """
        Get an existing EcdPolicyGroup resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['EcdPolicyGroupAuthorizeAccessPolicyRuleArgs', 'EcdPolicyGroupAuthorizeAccessPolicyRuleArgsDict']]]] authorize_access_policy_rules: The rule of authorize access rule. See `authorize_access_policy_rules` below.
        :param pulumi.Input[Sequence[pulumi.Input[Union['EcdPolicyGroupAuthorizeSecurityPolicyRuleArgs', 'EcdPolicyGroupAuthorizeSecurityPolicyRuleArgsDict']]]] authorize_security_policy_rules: The policy rule. See `authorize_security_policy_rules` below.
        :param pulumi.Input[str] camera_redirect: Whether to enable local camera redirection. Valid values: `on`, `off`.
        :param pulumi.Input[str] clipboard: The clipboard policy. Valid values: `off`, `read`, `readwrite`.
        :param pulumi.Input[str] domain_list: The list of domain.
        :param pulumi.Input[str] html_access: The access of html5. Valid values: `off`, `on`.
        :param pulumi.Input[str] html_file_transfer: The html5 file transfer. Valid values: `all`, `download`, `off`, `upload`.
        :param pulumi.Input[str] local_drive: Local drive redirect policy. Valid values: ` readwrite`, `off`, `read`.
        :param pulumi.Input[str] policy_group_name: The name of policy group.
        :param pulumi.Input[str] recording: Whether to enable screen recording. Valid values: `off`, `all-time`, `period`.
        :param pulumi.Input[str] recording_end_time: The end time of recording, value: `HH:MM:SS`. This return value is meaningful only when the value of `recording` is `period`.
        :param pulumi.Input[int] recording_expires: The screen recording video retention. Valid values between 30 and 180. This return value is meaningful only when the value of `recording` is `period` or `all-time`.
        :param pulumi.Input[int] recording_fps: The fps of recording. Valid values: `2`, `5`, `10`, `15`.
        :param pulumi.Input[str] recording_start_time: The start time of recording, value: `HH:MM:SS`. This return value is meaningful only when the value of `recording` is `period`.
        :param pulumi.Input[str] status: The status of policy.
        :param pulumi.Input[str] usb_redirect: The usb redirect policy. Valid values: `off`, `on`.
        :param pulumi.Input[str] visual_quality: The quality of visual. Valid values: `high`, `lossless`, `low`, `medium`.
        :param pulumi.Input[str] watermark: The watermark policy. Valid values: `off`, `on`.
        :param pulumi.Input[str] watermark_transparency: The watermark transparency. Valid values: `DARK`, `LIGHT`, `MIDDLE`.
        :param pulumi.Input[str] watermark_type: The type of watemark. Valid values: `EndUserId`, `HostName`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _EcdPolicyGroupState.__new__(_EcdPolicyGroupState)

        __props__.__dict__["authorize_access_policy_rules"] = authorize_access_policy_rules
        __props__.__dict__["authorize_security_policy_rules"] = authorize_security_policy_rules
        __props__.__dict__["camera_redirect"] = camera_redirect
        __props__.__dict__["clipboard"] = clipboard
        __props__.__dict__["domain_list"] = domain_list
        __props__.__dict__["html_access"] = html_access
        __props__.__dict__["html_file_transfer"] = html_file_transfer
        __props__.__dict__["local_drive"] = local_drive
        __props__.__dict__["policy_group_name"] = policy_group_name
        __props__.__dict__["recording"] = recording
        __props__.__dict__["recording_end_time"] = recording_end_time
        __props__.__dict__["recording_expires"] = recording_expires
        __props__.__dict__["recording_fps"] = recording_fps
        __props__.__dict__["recording_start_time"] = recording_start_time
        __props__.__dict__["status"] = status
        __props__.__dict__["usb_redirect"] = usb_redirect
        __props__.__dict__["visual_quality"] = visual_quality
        __props__.__dict__["watermark"] = watermark
        __props__.__dict__["watermark_transparency"] = watermark_transparency
        __props__.__dict__["watermark_type"] = watermark_type
        return EcdPolicyGroup(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="authorizeAccessPolicyRules")
    def authorize_access_policy_rules(self) -> pulumi.Output[Optional[Sequence['outputs.EcdPolicyGroupAuthorizeAccessPolicyRule']]]:
        """
        The rule of authorize access rule. See `authorize_access_policy_rules` below.
        """
        return pulumi.get(self, "authorize_access_policy_rules")

    @property
    @pulumi.getter(name="authorizeSecurityPolicyRules")
    def authorize_security_policy_rules(self) -> pulumi.Output[Optional[Sequence['outputs.EcdPolicyGroupAuthorizeSecurityPolicyRule']]]:
        """
        The policy rule. See `authorize_security_policy_rules` below.
        """
        return pulumi.get(self, "authorize_security_policy_rules")

    @property
    @pulumi.getter(name="cameraRedirect")
    def camera_redirect(self) -> pulumi.Output[str]:
        """
        Whether to enable local camera redirection. Valid values: `on`, `off`.
        """
        return pulumi.get(self, "camera_redirect")

    @property
    @pulumi.getter
    def clipboard(self) -> pulumi.Output[str]:
        """
        The clipboard policy. Valid values: `off`, `read`, `readwrite`.
        """
        return pulumi.get(self, "clipboard")

    @property
    @pulumi.getter(name="domainList")
    def domain_list(self) -> pulumi.Output[Optional[str]]:
        """
        The list of domain.
        """
        return pulumi.get(self, "domain_list")

    @property
    @pulumi.getter(name="htmlAccess")
    def html_access(self) -> pulumi.Output[str]:
        """
        The access of html5. Valid values: `off`, `on`.
        """
        return pulumi.get(self, "html_access")

    @property
    @pulumi.getter(name="htmlFileTransfer")
    def html_file_transfer(self) -> pulumi.Output[str]:
        """
        The html5 file transfer. Valid values: `all`, `download`, `off`, `upload`.
        """
        return pulumi.get(self, "html_file_transfer")

    @property
    @pulumi.getter(name="localDrive")
    def local_drive(self) -> pulumi.Output[str]:
        """
        Local drive redirect policy. Valid values: ` readwrite`, `off`, `read`.
        """
        return pulumi.get(self, "local_drive")

    @property
    @pulumi.getter(name="policyGroupName")
    def policy_group_name(self) -> pulumi.Output[Optional[str]]:
        """
        The name of policy group.
        """
        return pulumi.get(self, "policy_group_name")

    @property
    @pulumi.getter
    def recording(self) -> pulumi.Output[str]:
        """
        Whether to enable screen recording. Valid values: `off`, `all-time`, `period`.
        """
        return pulumi.get(self, "recording")

    @property
    @pulumi.getter(name="recordingEndTime")
    def recording_end_time(self) -> pulumi.Output[Optional[str]]:
        """
        The end time of recording, value: `HH:MM:SS`. This return value is meaningful only when the value of `recording` is `period`.
        """
        return pulumi.get(self, "recording_end_time")

    @property
    @pulumi.getter(name="recordingExpires")
    def recording_expires(self) -> pulumi.Output[int]:
        """
        The screen recording video retention. Valid values between 30 and 180. This return value is meaningful only when the value of `recording` is `period` or `all-time`.
        """
        return pulumi.get(self, "recording_expires")

    @property
    @pulumi.getter(name="recordingFps")
    def recording_fps(self) -> pulumi.Output[int]:
        """
        The fps of recording. Valid values: `2`, `5`, `10`, `15`.
        """
        return pulumi.get(self, "recording_fps")

    @property
    @pulumi.getter(name="recordingStartTime")
    def recording_start_time(self) -> pulumi.Output[Optional[str]]:
        """
        The start time of recording, value: `HH:MM:SS`. This return value is meaningful only when the value of `recording` is `period`.
        """
        return pulumi.get(self, "recording_start_time")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        The status of policy.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="usbRedirect")
    def usb_redirect(self) -> pulumi.Output[str]:
        """
        The usb redirect policy. Valid values: `off`, `on`.
        """
        return pulumi.get(self, "usb_redirect")

    @property
    @pulumi.getter(name="visualQuality")
    def visual_quality(self) -> pulumi.Output[str]:
        """
        The quality of visual. Valid values: `high`, `lossless`, `low`, `medium`.
        """
        return pulumi.get(self, "visual_quality")

    @property
    @pulumi.getter
    def watermark(self) -> pulumi.Output[str]:
        """
        The watermark policy. Valid values: `off`, `on`.
        """
        return pulumi.get(self, "watermark")

    @property
    @pulumi.getter(name="watermarkTransparency")
    def watermark_transparency(self) -> pulumi.Output[str]:
        """
        The watermark transparency. Valid values: `DARK`, `LIGHT`, `MIDDLE`.
        """
        return pulumi.get(self, "watermark_transparency")

    @property
    @pulumi.getter(name="watermarkType")
    def watermark_type(self) -> pulumi.Output[str]:
        """
        The type of watemark. Valid values: `EndUserId`, `HostName`.
        """
        return pulumi.get(self, "watermark_type")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetTransitRouterAvailableResourcesResult',
    'AwaitableGetTransitRouterAvailableResourcesResult',
    'get_transit_router_available_resources',
    'get_transit_router_available_resources_output',
]

@pulumi.output_type
class GetTransitRouterAvailableResourcesResult:
    """
    A collection of values returned by getTransitRouterAvailableResources.
    """
    def __init__(__self__, id=None, output_file=None, resources=None, support_multicast=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if resources and not isinstance(resources, list):
            raise TypeError("Expected argument 'resources' to be a list")
        pulumi.set(__self__, "resources", resources)
        if support_multicast and not isinstance(support_multicast, bool):
            raise TypeError("Expected argument 'support_multicast' to be a bool")
        pulumi.set(__self__, "support_multicast", support_multicast)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter
    def resources(self) -> Sequence['outputs.GetTransitRouterAvailableResourcesResourceResult']:
        """
        A list of Cen Transit Router Available Resources. Each element contains the following attributes:
        """
        return pulumi.get(self, "resources")

    @property
    @pulumi.getter(name="supportMulticast")
    def support_multicast(self) -> Optional[bool]:
        """
        (Available since v1.225.0) Indicates whether the zone supports the multicast feature.
        """
        return pulumi.get(self, "support_multicast")


class AwaitableGetTransitRouterAvailableResourcesResult(GetTransitRouterAvailableResourcesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetTransitRouterAvailableResourcesResult(
            id=self.id,
            output_file=self.output_file,
            resources=self.resources,
            support_multicast=self.support_multicast)


def get_transit_router_available_resources(output_file: Optional[str] = None,
                                           support_multicast: Optional[bool] = None,
                                           opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetTransitRouterAvailableResourcesResult:
    """
    This data source provides the CEN Transit Router Available Resources of the current Alibaba Cloud user.

    > **NOTE:** Available since v1.163.0.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.cen.get_transit_router_available_resources()
    pulumi.export("masterId", ids.resources[0].master_zones[0])
    pulumi.export("slaveId", ids.resources[0].slave_zones[0])
    ```


    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param bool support_multicast: Specifies whether to query only the zones in which the multicast feature is supported.
    """
    __args__ = dict()
    __args__['outputFile'] = output_file
    __args__['supportMulticast'] = support_multicast
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:cen/getTransitRouterAvailableResources:getTransitRouterAvailableResources', __args__, opts=opts, typ=GetTransitRouterAvailableResourcesResult).value

    return AwaitableGetTransitRouterAvailableResourcesResult(
        id=pulumi.get(__ret__, 'id'),
        output_file=pulumi.get(__ret__, 'output_file'),
        resources=pulumi.get(__ret__, 'resources'),
        support_multicast=pulumi.get(__ret__, 'support_multicast'))
def get_transit_router_available_resources_output(output_file: Optional[pulumi.Input[Optional[str]]] = None,
                                                  support_multicast: Optional[pulumi.Input[Optional[bool]]] = None,
                                                  opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetTransitRouterAvailableResourcesResult]:
    """
    This data source provides the CEN Transit Router Available Resources of the current Alibaba Cloud user.

    > **NOTE:** Available since v1.163.0.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.cen.get_transit_router_available_resources()
    pulumi.export("masterId", ids.resources[0].master_zones[0])
    pulumi.export("slaveId", ids.resources[0].slave_zones[0])
    ```


    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param bool support_multicast: Specifies whether to query only the zones in which the multicast feature is supported.
    """
    __args__ = dict()
    __args__['outputFile'] = output_file
    __args__['supportMulticast'] = support_multicast
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:cen/getTransitRouterAvailableResources:getTransitRouterAvailableResources', __args__, opts=opts, typ=GetTransitRouterAvailableResourcesResult)
    return __ret__.apply(lambda __response__: GetTransitRouterAvailableResourcesResult(
        id=pulumi.get(__response__, 'id'),
        output_file=pulumi.get(__response__, 'output_file'),
        resources=pulumi.get(__response__, 'resources'),
        support_multicast=pulumi.get(__response__, 'support_multicast')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetExecutionsExecutionResult',
    'GetFlowsFlowResult',
    'GetSchedulesScheduleResult',
]

@pulumi.output_type
class GetExecutionsExecutionResult(dict):
    def __init__(__self__, *,
                 execution_name: str,
                 flow_name: str,
                 id: str,
                 input: str,
                 output: str,
                 started_time: str,
                 status: str,
                 stopped_time: str):
        """
        :param str execution_name: The name of the execution.
        :param str flow_name: The name of the flow.
        :param str id: The ID of the Execution. The value formats as `<flow_name>:<execution_name>`.
        :param str input: The Input information for this execution.
        :param str output: The output of the execution.
        :param str started_time: The started time of the execution.
        :param str status: The status of the resource.
        :param str stopped_time: The stopped time of the execution.
        """
        pulumi.set(__self__, "execution_name", execution_name)
        pulumi.set(__self__, "flow_name", flow_name)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "input", input)
        pulumi.set(__self__, "output", output)
        pulumi.set(__self__, "started_time", started_time)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "stopped_time", stopped_time)

    @property
    @pulumi.getter(name="executionName")
    def execution_name(self) -> str:
        """
        The name of the execution.
        """
        return pulumi.get(self, "execution_name")

    @property
    @pulumi.getter(name="flowName")
    def flow_name(self) -> str:
        """
        The name of the flow.
        """
        return pulumi.get(self, "flow_name")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Execution. The value formats as `<flow_name>:<execution_name>`.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def input(self) -> str:
        """
        The Input information for this execution.
        """
        return pulumi.get(self, "input")

    @property
    @pulumi.getter
    def output(self) -> str:
        """
        The output of the execution.
        """
        return pulumi.get(self, "output")

    @property
    @pulumi.getter(name="startedTime")
    def started_time(self) -> str:
        """
        The started time of the execution.
        """
        return pulumi.get(self, "started_time")

    @property
    @pulumi.getter
    def status(self) -> str:
        """
        The status of the resource.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="stoppedTime")
    def stopped_time(self) -> str:
        """
        The stopped time of the execution.
        """
        return pulumi.get(self, "stopped_time")


@pulumi.output_type
class GetFlowsFlowResult(dict):
    def __init__(__self__, *,
                 definition: str,
                 description: str,
                 flow_id: str,
                 id: str,
                 last_modified_time: str,
                 name: str,
                 role_arn: str,
                 type: str):
        """
        :param str definition: The definition of the flow. It must comply with the Flow Definition Language (FDL) syntax.
        :param str description: The description of the flow.
        :param str flow_id: The unique ID of the flow.
        :param str id: The ID of the Flow.
        :param str last_modified_time: The time when the flow was last modified.
        :param str name: The name of the flow. The name must be unique in an Alibaba Cloud account.
        :param str role_arn: The ARN of the specified RAM role that Serverless Workflow uses to assume the role when Serverless Workflow executes a flow.
        :param str type: The type of the flow. Set the value to `FDL`.
        """
        pulumi.set(__self__, "definition", definition)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "flow_id", flow_id)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "last_modified_time", last_modified_time)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "role_arn", role_arn)
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def definition(self) -> str:
        """
        The definition of the flow. It must comply with the Flow Definition Language (FDL) syntax.
        """
        return pulumi.get(self, "definition")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        The description of the flow.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="flowId")
    def flow_id(self) -> str:
        """
        The unique ID of the flow.
        """
        return pulumi.get(self, "flow_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Flow.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="lastModifiedTime")
    def last_modified_time(self) -> str:
        """
        The time when the flow was last modified.
        """
        return pulumi.get(self, "last_modified_time")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The name of the flow. The name must be unique in an Alibaba Cloud account.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="roleArn")
    def role_arn(self) -> str:
        """
        The ARN of the specified RAM role that Serverless Workflow uses to assume the role when Serverless Workflow executes a flow.
        """
        return pulumi.get(self, "role_arn")

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        The type of the flow. Set the value to `FDL`.
        """
        return pulumi.get(self, "type")


@pulumi.output_type
class GetSchedulesScheduleResult(dict):
    def __init__(__self__, *,
                 cron_expression: str,
                 description: str,
                 enable: bool,
                 id: str,
                 last_modified_time: str,
                 payload: str,
                 schedule_id: str,
                 schedule_name: str):
        """
        :param str cron_expression: The CRON expression of the time-based schedule to be created.
        :param str description: The description of the time-based schedule to be created.
        :param bool enable: Specifies whether to enable the time-based schedule you want to create.
        :param str id: The ID of the Schedule.
        :param str last_modified_time: The time when the time-based schedule was last updated.
        :param str payload: The trigger message of the time-based schedule to be created. It must be in JSON object format.
        :param str schedule_id: The ID of the time-based schedule.
        :param str schedule_name: The name of the time-based schedule to be created.
        """
        pulumi.set(__self__, "cron_expression", cron_expression)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "enable", enable)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "last_modified_time", last_modified_time)
        pulumi.set(__self__, "payload", payload)
        pulumi.set(__self__, "schedule_id", schedule_id)
        pulumi.set(__self__, "schedule_name", schedule_name)

    @property
    @pulumi.getter(name="cronExpression")
    def cron_expression(self) -> str:
        """
        The CRON expression of the time-based schedule to be created.
        """
        return pulumi.get(self, "cron_expression")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        The description of the time-based schedule to be created.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def enable(self) -> bool:
        """
        Specifies whether to enable the time-based schedule you want to create.
        """
        return pulumi.get(self, "enable")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Schedule.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="lastModifiedTime")
    def last_modified_time(self) -> str:
        """
        The time when the time-based schedule was last updated.
        """
        return pulumi.get(self, "last_modified_time")

    @property
    @pulumi.getter
    def payload(self) -> str:
        """
        The trigger message of the time-based schedule to be created. It must be in JSON object format.
        """
        return pulumi.get(self, "payload")

    @property
    @pulumi.getter(name="scheduleId")
    def schedule_id(self) -> str:
        """
        The ID of the time-based schedule.
        """
        return pulumi.get(self, "schedule_id")

    @property
    @pulumi.getter(name="scheduleName")
    def schedule_name(self) -> str:
        """
        The name of the time-based schedule to be created.
        """
        return pulumi.get(self, "schedule_name")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['PolicyArgs', 'Policy']

@pulumi.input_type
class PolicyArgs:
    def __init__(__self__, *,
                 access_control_rules: pulumi.Input[str],
                 kms_instance_id: pulumi.Input[str],
                 permissions: pulumi.Input[Sequence[pulumi.Input[str]]],
                 policy_name: pulumi.Input[str],
                 resources: pulumi.Input[Sequence[pulumi.Input[str]]],
                 description: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Policy resource.
        :param pulumi.Input[str] access_control_rules: Network Rules in JSON struct.
        :param pulumi.Input[str] kms_instance_id: KMS instance .
        :param pulumi.Input[Sequence[pulumi.Input[str]]] permissions: Allowed permissions (RBAC)Optional values:"RbacPermission/Template/CryptoServiceKeyUser" and "RbacPermission/Template/CryptoServiceSecretUser".
        :param pulumi.Input[str] policy_name: Policy Name.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] resources: The resources that the permission policy allows to access.Use "key/${KeyId}" or "key/*"  to specify a key or all keys.Use "secret/${SecretName}" or "secret/*" to specify a secret or all secrets.
        :param pulumi.Input[str] description: Description.
        """
        pulumi.set(__self__, "access_control_rules", access_control_rules)
        pulumi.set(__self__, "kms_instance_id", kms_instance_id)
        pulumi.set(__self__, "permissions", permissions)
        pulumi.set(__self__, "policy_name", policy_name)
        pulumi.set(__self__, "resources", resources)
        if description is not None:
            pulumi.set(__self__, "description", description)

    @property
    @pulumi.getter(name="accessControlRules")
    def access_control_rules(self) -> pulumi.Input[str]:
        """
        Network Rules in JSON struct.
        """
        return pulumi.get(self, "access_control_rules")

    @access_control_rules.setter
    def access_control_rules(self, value: pulumi.Input[str]):
        pulumi.set(self, "access_control_rules", value)

    @property
    @pulumi.getter(name="kmsInstanceId")
    def kms_instance_id(self) -> pulumi.Input[str]:
        """
        KMS instance .
        """
        return pulumi.get(self, "kms_instance_id")

    @kms_instance_id.setter
    def kms_instance_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "kms_instance_id", value)

    @property
    @pulumi.getter
    def permissions(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        """
        Allowed permissions (RBAC)Optional values:"RbacPermission/Template/CryptoServiceKeyUser" and "RbacPermission/Template/CryptoServiceSecretUser".
        """
        return pulumi.get(self, "permissions")

    @permissions.setter
    def permissions(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "permissions", value)

    @property
    @pulumi.getter(name="policyName")
    def policy_name(self) -> pulumi.Input[str]:
        """
        Policy Name.
        """
        return pulumi.get(self, "policy_name")

    @policy_name.setter
    def policy_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "policy_name", value)

    @property
    @pulumi.getter
    def resources(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        """
        The resources that the permission policy allows to access.Use "key/${KeyId}" or "key/*"  to specify a key or all keys.Use "secret/${SecretName}" or "secret/*" to specify a secret or all secrets.
        """
        return pulumi.get(self, "resources")

    @resources.setter
    def resources(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "resources", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)


@pulumi.input_type
class _PolicyState:
    def __init__(__self__, *,
                 access_control_rules: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 kms_instance_id: Optional[pulumi.Input[str]] = None,
                 permissions: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 policy_name: Optional[pulumi.Input[str]] = None,
                 resources: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        Input properties used for looking up and filtering Policy resources.
        :param pulumi.Input[str] access_control_rules: Network Rules in JSON struct.
        :param pulumi.Input[str] description: Description.
        :param pulumi.Input[str] kms_instance_id: KMS instance .
        :param pulumi.Input[Sequence[pulumi.Input[str]]] permissions: Allowed permissions (RBAC)Optional values:"RbacPermission/Template/CryptoServiceKeyUser" and "RbacPermission/Template/CryptoServiceSecretUser".
        :param pulumi.Input[str] policy_name: Policy Name.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] resources: The resources that the permission policy allows to access.Use "key/${KeyId}" or "key/*"  to specify a key or all keys.Use "secret/${SecretName}" or "secret/*" to specify a secret or all secrets.
        """
        if access_control_rules is not None:
            pulumi.set(__self__, "access_control_rules", access_control_rules)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if kms_instance_id is not None:
            pulumi.set(__self__, "kms_instance_id", kms_instance_id)
        if permissions is not None:
            pulumi.set(__self__, "permissions", permissions)
        if policy_name is not None:
            pulumi.set(__self__, "policy_name", policy_name)
        if resources is not None:
            pulumi.set(__self__, "resources", resources)

    @property
    @pulumi.getter(name="accessControlRules")
    def access_control_rules(self) -> Optional[pulumi.Input[str]]:
        """
        Network Rules in JSON struct.
        """
        return pulumi.get(self, "access_control_rules")

    @access_control_rules.setter
    def access_control_rules(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "access_control_rules", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="kmsInstanceId")
    def kms_instance_id(self) -> Optional[pulumi.Input[str]]:
        """
        KMS instance .
        """
        return pulumi.get(self, "kms_instance_id")

    @kms_instance_id.setter
    def kms_instance_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "kms_instance_id", value)

    @property
    @pulumi.getter
    def permissions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Allowed permissions (RBAC)Optional values:"RbacPermission/Template/CryptoServiceKeyUser" and "RbacPermission/Template/CryptoServiceSecretUser".
        """
        return pulumi.get(self, "permissions")

    @permissions.setter
    def permissions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "permissions", value)

    @property
    @pulumi.getter(name="policyName")
    def policy_name(self) -> Optional[pulumi.Input[str]]:
        """
        Policy Name.
        """
        return pulumi.get(self, "policy_name")

    @policy_name.setter
    def policy_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "policy_name", value)

    @property
    @pulumi.getter
    def resources(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The resources that the permission policy allows to access.Use "key/${KeyId}" or "key/*"  to specify a key or all keys.Use "secret/${SecretName}" or "secret/*" to specify a secret or all secrets.
        """
        return pulumi.get(self, "resources")

    @resources.setter
    def resources(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "resources", value)


class Policy(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_control_rules: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 kms_instance_id: Optional[pulumi.Input[str]] = None,
                 permissions: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 policy_name: Optional[pulumi.Input[str]] = None,
                 resources: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 __props__=None):
        """
        Provides a KMS Policy resource. Permission policies which can be bound to the Application Access Points.

        For information about KMS Policy and how to use it, see [What is Policy](https://www.alibabacloud.com/help/zh/key-management-service/latest/api-createpolicy).

        > **NOTE:** Available since v1.210.0.

        ## Import

        KMS Policy can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:kms/policy:Policy example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] access_control_rules: Network Rules in JSON struct.
        :param pulumi.Input[str] description: Description.
        :param pulumi.Input[str] kms_instance_id: KMS instance .
        :param pulumi.Input[Sequence[pulumi.Input[str]]] permissions: Allowed permissions (RBAC)Optional values:"RbacPermission/Template/CryptoServiceKeyUser" and "RbacPermission/Template/CryptoServiceSecretUser".
        :param pulumi.Input[str] policy_name: Policy Name.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] resources: The resources that the permission policy allows to access.Use "key/${KeyId}" or "key/*"  to specify a key or all keys.Use "secret/${SecretName}" or "secret/*" to specify a secret or all secrets.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: PolicyArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a KMS Policy resource. Permission policies which can be bound to the Application Access Points.

        For information about KMS Policy and how to use it, see [What is Policy](https://www.alibabacloud.com/help/zh/key-management-service/latest/api-createpolicy).

        > **NOTE:** Available since v1.210.0.

        ## Import

        KMS Policy can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:kms/policy:Policy example <id>
        ```

        :param str resource_name: The name of the resource.
        :param PolicyArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(PolicyArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_control_rules: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 kms_instance_id: Optional[pulumi.Input[str]] = None,
                 permissions: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 policy_name: Optional[pulumi.Input[str]] = None,
                 resources: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = PolicyArgs.__new__(PolicyArgs)

            if access_control_rules is None and not opts.urn:
                raise TypeError("Missing required property 'access_control_rules'")
            __props__.__dict__["access_control_rules"] = access_control_rules
            __props__.__dict__["description"] = description
            if kms_instance_id is None and not opts.urn:
                raise TypeError("Missing required property 'kms_instance_id'")
            __props__.__dict__["kms_instance_id"] = kms_instance_id
            if permissions is None and not opts.urn:
                raise TypeError("Missing required property 'permissions'")
            __props__.__dict__["permissions"] = permissions
            if policy_name is None and not opts.urn:
                raise TypeError("Missing required property 'policy_name'")
            __props__.__dict__["policy_name"] = policy_name
            if resources is None and not opts.urn:
                raise TypeError("Missing required property 'resources'")
            __props__.__dict__["resources"] = resources
        super(Policy, __self__).__init__(
            'alicloud:kms/policy:Policy',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            access_control_rules: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            kms_instance_id: Optional[pulumi.Input[str]] = None,
            permissions: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            policy_name: Optional[pulumi.Input[str]] = None,
            resources: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None) -> 'Policy':
        """
        Get an existing Policy resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] access_control_rules: Network Rules in JSON struct.
        :param pulumi.Input[str] description: Description.
        :param pulumi.Input[str] kms_instance_id: KMS instance .
        :param pulumi.Input[Sequence[pulumi.Input[str]]] permissions: Allowed permissions (RBAC)Optional values:"RbacPermission/Template/CryptoServiceKeyUser" and "RbacPermission/Template/CryptoServiceSecretUser".
        :param pulumi.Input[str] policy_name: Policy Name.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] resources: The resources that the permission policy allows to access.Use "key/${KeyId}" or "key/*"  to specify a key or all keys.Use "secret/${SecretName}" or "secret/*" to specify a secret or all secrets.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _PolicyState.__new__(_PolicyState)

        __props__.__dict__["access_control_rules"] = access_control_rules
        __props__.__dict__["description"] = description
        __props__.__dict__["kms_instance_id"] = kms_instance_id
        __props__.__dict__["permissions"] = permissions
        __props__.__dict__["policy_name"] = policy_name
        __props__.__dict__["resources"] = resources
        return Policy(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="accessControlRules")
    def access_control_rules(self) -> pulumi.Output[str]:
        """
        Network Rules in JSON struct.
        """
        return pulumi.get(self, "access_control_rules")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        Description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="kmsInstanceId")
    def kms_instance_id(self) -> pulumi.Output[str]:
        """
        KMS instance .
        """
        return pulumi.get(self, "kms_instance_id")

    @property
    @pulumi.getter
    def permissions(self) -> pulumi.Output[Sequence[str]]:
        """
        Allowed permissions (RBAC)Optional values:"RbacPermission/Template/CryptoServiceKeyUser" and "RbacPermission/Template/CryptoServiceSecretUser".
        """
        return pulumi.get(self, "permissions")

    @property
    @pulumi.getter(name="policyName")
    def policy_name(self) -> pulumi.Output[str]:
        """
        Policy Name.
        """
        return pulumi.get(self, "policy_name")

    @property
    @pulumi.getter
    def resources(self) -> pulumi.Output[Sequence[str]]:
        """
        The resources that the permission policy allows to access.Use "key/${KeyId}" or "key/*"  to specify a key or all keys.Use "secret/${SecretName}" or "secret/*" to specify a secret or all secrets.
        """
        return pulumi.get(self, "resources")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from .. import _utilities
import typing
# Export this package's modules as members:
from .ad_connector_directory import *
from .ad_connector_office_site import *
from .bundle import *
from .command import *
from .custom_property import *
from .desktop import *
from .ecd_policy_group import *
from .get_ad_connector_directories import *
from .get_ad_connector_office_sites import *
from .get_bundles import *
from .get_commands import *
from .get_custom_properties import *
from .get_desktop_types import *
from .get_desktops import *
from .get_images import *
from .get_nas_file_systems import *
from .get_network_packages import *
from .get_policy_groups import *
from .get_ram_directories import *
from .get_simple_office_sites import *
from .get_snapshots import *
from .get_users import *
from .get_zones import *
from .image import *
from .nas_file_system import *
from .network_package import *
from .ram_directory import *
from .simple_office_site import *
from .snapshot import *
from .user import *
from ._inputs import *
from . import outputs
